@@ -1,5 +1,4 @@
 from ._abstract import AbstractScraper
-from ._grouping_utils import group_ingredients
 
 
 class AddAPinch(AbstractScraper):
@@ -7,14 +6,6 @@ class AddAPinch(AbstractScraper):
     def host(cls):
         return "addapinch.com"
 
-    def ingredient_groups(self):
-        return group_ingredients(
-            self.ingredients(),
-            self.soup,
-            ".wprm-recipe-ingredient-group h4",
-            ".wprm-recipe-ingredient-group li",
-        )
-
     def equipment(self):
         return list(
             dict.fromkeys(
