@@ -1,5 +1,4 @@
 from ._abstract import AbstractScraper
-from ._grouping_utils import group_ingredients
 from ._utils import get_equipment
 
 
@@ -13,14 +12,6 @@ class CookiesAndCups(AbstractScraper):
             ".post-author-detail.post-author-by .entry-author-name a"
         ).get_text(strip=True)
 
-    def ingredient_groups(self):
-        return group_ingredients(
-            self.ingredients(),
-            self.soup,
-            ".tasty-recipes-ingredients-body p strong",
-            ".tasty-recipes-ingredients-body ul li",
-        )
-
     def equipment(self):
         equipment_items = self.soup.select(
             ".tasty-recipes-instructions-body ol li a.tasty-link"
