@@ -28,7 +28,7 @@ class Kochbucher(AbstractScraper):
     def ingredients(self):
         zutaten_heading = self.soup.find("p", string="Zutaten")
         if zutaten_heading is not None:
-            next_p_element = zutaten_heading.find_next("p")
+            next_p_element = zutaten_heading.find_next(name="p")
             if next_p_element is not None:
                 ingredients_list = next_p_element.get_text().split("\n")
                 ingredients_list = [
@@ -41,7 +41,7 @@ class Kochbucher(AbstractScraper):
     def instructions(self):
         zubereitung_heading = self.soup.find("p", string="Zubereitung")
         if zubereitung_heading is not None:
-            next_p_element = zubereitung_heading.find_next("p")
+            next_p_element = zubereitung_heading.find_next(name="p")
             if next_p_element is not None:
                 raw_instructions = next_p_element.get_text().replace("– ", "")
                 if isinstance(raw_instructions, str):
