@@ -17,8 +17,8 @@ class RosannaPansino(AbstractScraper):
     def ingredients(self):
         ingredients = (
             self.soup.find("div", {"class": "recipe-left"})
-            .find_next("em", string="Ingredients")
-            .find_next_sibling("ul")
+            .find_next(name="em", string="Ingredients")
+            .find_next_sibling(name="ul")
             .find_all("li")
         )
         return [normalize_string(ingredient.get_text()) for ingredient in ingredients]
@@ -26,7 +26,7 @@ class RosannaPansino(AbstractScraper):
     def instructions(self):
         instructions = (
             self.soup.find("div", {"class": "recipe-right"})
-            .find_next("ol")
+            .find_next(name="ol")
             .find_all("li")
         )
         return "\n".join(
