@@ -1,8 +1,8 @@
 from ._abstract import AbstractScraper
-from ._utils import get_equipment
+from ._wprm import WPRMMixin
 
 
-class StaySnatched(AbstractScraper):
+class StaySnatched(WPRMMixin, AbstractScraper):
     @classmethod
     def host(cls):
         return "staysnatched.com"
@@ -15,11 +15,3 @@ class StaySnatched(AbstractScraper):
             },
         )
         return author_element.find("a").get_text() if author_element else "Unknown"
-
-    def equipment(self):
-        equipment_items = [
-            text
-            for equip in self.soup.find_all("div", class_="wprm-recipe-equipment-name")
-            if (text := equip.get_text())
-        ]
-        return get_equipment(equipment_items)
